#!/usr/bin/python3

# __init__.py
# Date:  15/08/2019
# Author: Eugeniu Costetchi
# Email: costezki.eugen@gmail.com

import logging.config

__docformat__ = "restructuredtext en"

__version__ = "0.2.12"
__date__ = "2022-02-02"

# logging.config.fileConfig('logging.conf')
